## v0.7.0 (2025-10-02)

### Feat

- drop support for python 3.9 (#377)
- add support for python 3.13 (#376)
- **parser**: add tag access fields to Message objects (#308)
- drop python 3.8 support

### Fix

- **deps**: only pin build dependencies
- don't override deps for test env
- correct __all__ in util package
- correct type annotations for type inference
- update zsh-plugins feature source to use the correct repository
- Remove codeql config to use default setup

### Refactor

- cleanup imports
- add ssort to sort module members
- add version data to root module

## v0.6.0 (2024-04-16)

### Feat

- switch to Self type for constructor method returns

## v0.5.1 (2024-04-15)

### Refactor

- add Final and TypeAlias annotations

## v0.5.0 (2024-04-15)

## v0.4.0 (2024-04-14)

## v0.3.0 (2019-08-18)

## v0.2.1 (2019-02-01)

## v0.2.0 (2019-01-06)

## v0.1.5 (2018-10-12)

## v0.1.4 (2018-02-12)

## v0.1.3.1 (2018-02-12)

## v0.1.3 (2018-02-04)

## v0.1.2 (2017-11-25)

## v0.1.1 (2017-11-25)

## v0.1.0 (2017-11-25)
